@REM  Licensed Materials - Property of IBM
@REM  5724-M24
@REM  Copyright IBM Corporation 2008,2009. All Rights Reserved.
@REM  US Government Users Restricted Rights- Use, duplication or disclosure
@REM  restricted by GSA ADP Schedule Contract with IBM Corp.
@ECHO OFF
@SETLOCAL

@REM Monitor Model Deploy Tool

@REM Launch Arguments:
@REM
@REM -pi <pifile.zip>           Specify the input project interchange file.
@REM -ear <earfile.ear>         Override the name of the generated EAR file.
@REM -mm <mmfile.mm>            Specify the monitor model to use in the project interchange file.
@REM -ejbdeploy                 Run ejbDeploy against the ear file.
@REM -novalidation              Disable monitor model validation.
@REM -ignorevalidation          Do not halt for validation errors.
@REM -keep                      Do not cleanup on exit.
@REM -w <workingdir>            Specify temporary working directory.

FOR /D %%F IN ("%~dp0..\runtimes\base_v61_stub" "%~dp0..\runtimes\bi_v62_stub" "%~dp0..\runtimes\base_v61" "%~dp0..\runtimes\bi_v62") DO (
	SET WAS_HOME=%%~fF
)

FOR /D %%F IN ("%~dp0..") DO (
	SET TOOLKIT_HOME=%%~fF
)

FOR %%F IN ("%TOOLKIT_HOME%\plugins\org.eclipse.equinox.launcher_*.jar") DO (
	SET STARTUP_JAR=%%F
)

:ARGS_LOOP
IF "%~1"=="" GOTO ARGS_LOOP_EXIT
IF "%~1"=="-keep" (
    SET KEEP=TRUE
) ELSE IF "%~1"=="-w" (
@REM use quotes in case a filename contains parentheses like "my (new) file.ear"
    SET WORK_DIR="%~f2"
    SHIFT
)
SHIFT
GOTO ARGS_LOOP
:ARGS_LOOP_EXIT

IF NOT DEFINED WORK_DIR (
	SET WORK_DIR=%TEMP%
) ELSE (
@REM remove quotes if they exist
	SET WORK_DIR=%WORK_DIR:"=%
)

IF NOT DEFINED KEEP (
	SET KEEP=FALSE
)
ECHO KEEP: %KEEP%

SET WORKSPACE_DIR=%WORK_DIR%\mmdeploy-%RANDOM%

SET JAVA_EXE=%TOOLKIT_HOME%\jdk\jre\bin\java.exe 

IF NOT EXIST "%WORKSPACE_DIR%" (
	MKDIR "%WORKSPACE_DIR%"
)

SET LOGGING_PROPS=%WORKSPACE_DIR%\logging.properties
ECHO com.ibm.wbimonitor.handlers=com.ibm.wbimonitor.deploy.mmdeploy.launcher.ConsoleHandler>>"%LOGGING_PROPS%"
ECHO com.ibm.wbimonitor.useParentHandlers=false>>"%LOGGING_PROPS%"
ECHO com.ibm.wbimonitor.deploy.mmdeploy.launcher.ConsoleHandler.level=FINEST>>"%LOGGING_PROPS%"
ECHO com.ibm.wbimonitor.level=FINEST>>"%LOGGING_PROPS%"

REM SET JAVA_OPTIONS=-Xquickstart
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xms512m
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xss2048k
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xmaxf0.1
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xminf0.05
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xmx1024m
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xmnx64m
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xgcpolicy:gencon
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xscmx96m 
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xshareclasses:name=IBMSDP_%u
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -Xnolinenumbers
REM SET JAVA_OPTIONS=%JAVA_OPTIONS% -XX:MaxPermSize=512M 
SET JAVA_OPTIONS=%JAVA_OPTIONS% -Djava.util.logging.config.file="%LOGGING_PROPS:\=/%"

SET ECLIPSE_OPTIONS=-application com.ibm.wbimonitor.deploy.mmdeploy.MonitoringModelDeploy -data "%WORKSPACE_DIR%"

ECHO [%DATE% %TIME%] Using work directory %WORK_DIR%
ECHO [%DATE% %TIME%] Using workspace %WORKSPACE_DIR%
ECHO [%DATE% %TIME%] Using WAS located at %WAS_HOME%
ECHO [%DATE% %TIME%] Using toolkit located at %TOOLKIT_HOME%
ECHO [%DATE% %TIME%] Using the launcher %STARTUP_JAR%
ECHO [%DATE% %TIME%] Using the Java executable %JAVA_EXE%
REM ECHO [%DATE% %TIME%] Using the Java options: %JAVA_OPTIONS%
REM ECHO [%DATE% %TIME%] Using the Eclipse options: %ECLIPSE_OPTIONS%

"%JAVA_EXE%" -jar "%STARTUP_JAR%" %JAVA_OPTIONS% %ECLIPSE_OPTIONS% %* 2>"%WORKSPACE_DIR%\stderr.log"
SET RETURN_CODE=%ERRORLEVEL%

IF "%KEEP%"=="FALSE" (
	ECHO [%DATE% %TIME%] Cleaning up %WORKSPACE_DIR%
	RD /S/Q "%WORKSPACE_DIR%"
)

EXIT /B %RETURN_CODE%
